summaryrefslogtreecommitdiffstats
path: root/.config/i3
diff options
context:
space:
mode:
Diffstat (limited to '.config/i3')
-rwxr-xr-x.config/i3/lock.sh10
1 files changed, 8 insertions, 2 deletions
diff --git a/.config/i3/lock.sh b/.config/i3/lock.sh
index 4d74451..4031757 100755
--- a/.config/i3/lock.sh
+++ b/.config/i3/lock.sh
@@ -1,5 +1,8 @@
#!/bin/bash
+# Approximate timeout rate in milliseconds (checked every 5 seconds).
+timeout="10000"
+
# Take a screenshot:
scrot /tmp/screen.png
@@ -16,5 +19,8 @@ mpc pause
# Lock it up!
i3lock -e -f -c 000000 -i /tmp/screen.png
-# If still locked after 20 seconds, turn off screen.
-sleep 20 && pgrep i3lock && xset dpms force off
+# If still locked after $timeout milliseconds, turn off screen.
+while [[ $(pgrep -x i3lock) ]]; do
+ [[ $timeout -lt $(xssstate -i) ]] && xset dpms force off
+ sleep 5
+done